@@ -1,5 +1,3 @@
-# $Id: Kex.pm,v 1.24 2009/02/02 01:18:27 turnstep Exp $
-
 package Net::SSH::Perl::Kex;
 use strict;
 use warnings;
@@ -75,7 +73,7 @@ sub exchange {
     }
     if ($ssh->config->get('compression')) {
         $proposal[ PROPOSAL_COMP_ALGS_CTOS ] =
-        $proposal[ PROPOSAL_COMP_ALGS_STOC ] = "zlib";
+        $proposal[ PROPOSAL_COMP_ALGS_STOC ] = "zlib,none";
     }
     else {
         $proposal[ PROPOSAL_COMP_ALGS_CTOS ] =
@@ -90,7 +88,7 @@ sub exchange {
     $proposal[ PROPOSAL_KEX_ALGS ] .= ',ext-info-c'
         if $proposal[ PROPOSAL_KEX_ALGS ] !~ /ext-info-c/;
     if (my $macs = $ssh->config->get('macs')) {
-        $proposal[ PROPOSAL_MAC_ALGS_CTOS ] = 
+        $proposal[ PROPOSAL_MAC_ALGS_CTOS ] =
         $proposal[ PROPOSAL_MAC_ALGS_STOC ] = $macs;
     }
 
@@ -221,9 +219,14 @@ sub choose_kex {
     $kex->{algorithm} = $name;
     my %kexmap = (
         &KEX_CURVE25519_SHA256 => 'C25519',
+        &KEX_CURVE25519_SHA256_ALIAS
+                               => 'C25519',
         &KEX_DH_GEX_SHA256     => 'DHGEXSHA256',
         &KEX_DH_GEX_SHA1       => 'DHGEXSHA1',
-        &KEX_DH14              => 'DH14',
+        &KEX_DH14_SHA1         => 'DH14SHA1',
+        &KEX_DH14_SHA256       => 'DH14SHA256',
+        &KEX_DH16_SHA512       => 'DH16SHA512',
+        &KEX_DH18_SHA512       => 'DH18SHA512',
         &KEX_DH1               => 'DH1'
     );
     if (my $pkg = $kexmap{$name}) {
