@@ -1,5 +1,3 @@
-# $Id: Packet.pm,v 1.25 2008/09/24 19:21:20 turnstep Exp $
-
 package Net::SSH::Perl::Packet;
 
 use strict;
@@ -145,7 +143,7 @@ sub read_poll_ssh1 {
         $buffer->append($inflated);
     }
 
-    my $type = unpack "c", $buffer->bytes(0, 1, "");
+    my $type = unpack "C", $buffer->bytes(0, 1, "");
     $class->new($ssh,
         type => $type,
         data => $buffer);
@@ -239,7 +237,7 @@ sub read_poll_ssh2 {
 
     $ssh->{session}{seqnr_in}++;
 
-    my $padlen = unpack "c", $buffer->bytes(4-$aadlen, 1);
+    my $padlen = unpack "C", $buffer->bytes(4-$aadlen, 1);
     $ssh->fatal_disconnect("Corrupted padlen $padlen on input")
         unless $padlen >= 4;
 
@@ -253,7 +251,7 @@ sub read_poll_ssh2 {
         $buffer->append($inflated);
     }
 
-    my $type = unpack "c", $buffer->bytes(0, 1, '');
+    my $type = unpack "C", $buffer->bytes(0, 1, '');
     $ssh->{session}{_last_packet_length} = 0;
     $class->new($ssh, type => $type, data => $buffer);
 }
@@ -356,7 +354,7 @@ sub send_ssh2 {
     $buffer->append($junk);
 
     my $packet_len = $buffer->length + 1;
-    $buffer->bytes(0, 0, pack("c", $padlen));
+    $buffer->bytes(0, 0, pack("C", $padlen));
     $buffer->bytes(0, 0, pack("N", $packet_len)) unless $mac && $mac->etm;
 
     my $out = $ciph && $ciph->enabled ? $ciph->encrypt($buffer->bytes,$seqnr,$aadlen) : $buffer->bytes;
@@ -367,7 +365,7 @@ sub send_ssh2 {
         my $data = $mac->etm ? $out : $buffer->bytes;
         $macbuf = $mac->hmac(pack("N", $seqnr) . $data);
     }
- 
+
     my $output = Net::SSH::Perl::Buffer->new( MP => 'SSH2' );
     $output->append($out);
     $output->append($macbuf) if $mac && $mac->enabled;
