@@ -1,7 +1,6 @@
-# $Id: SSH1.pm,v 1.24 2009/01/26 01:05:00 turnstep Exp $
-
 package Net::SSH::Perl::SSH1;
 use strict;
+use warnings;
 
 use Net::SSH::Perl::Packet;
 use Net::SSH::Perl::Buffer;
@@ -18,6 +17,11 @@ use base qw( Net::SSH::Perl );
 
 use Math::GMP;
 use Carp qw( croak );
+use File::Spec::Functions qw( catfile );
+use File::HomeDir ();
+
+use vars qw( $VERSION $CONFIG $HOSTNAME );
+$VERSION = $Net::SSH::Perl::VERSION;
 
 sub version_string {
     my $class = shift;
@@ -27,22 +31,27 @@ sub version_string {
 
 sub _proto_init {
     my $ssh = shift;
-    my $home = $ENV{HOME} || (getpwuid($>))[7];
-    unless ($ssh->{config}->get('user_known_hosts')) {
+    my $home = File::HomeDir->my_home;
+    my $config = $ssh->{config};
+
+    unless ($config->get('user_known_hosts')) {
         defined $home or croak "Cannot determine home directory, please set the environment variable HOME";
-        $ssh->{config}->set('user_known_hosts', "$home/.ssh/known_hosts");
+        $config->set('user_known_hosts', catfile($home, '.ssh', 'known_hosts'));
     }
-    unless ($ssh->{config}->get('global_known_hosts')) {
-        $ssh->{config}->set('global_known_hosts', "/etc/ssh_known_hosts");
+    unless ($config->get('global_known_hosts')) {
+        my $glob_known_hosts = $^O eq 'MSWin32'
+          ? catfile( $ENV{WINDIR}, 'ssh_known_hosts' )
+          : '/etc/ssh_known_hosts';
+        $config->set('global_known_hosts', $glob_known_hosts );
     }
-    unless (my $if = $ssh->{config}->get('identity_files')) {
+    unless (my $if = $config->get('identity_files')) {
         defined $home or croak "Cannot determine home directory, please set the environment variable HOME";
-        $ssh->{config}->set('identity_files', [ "$home/.ssh/identity" ]);
+        $config->set('identity_files', [ catfile($home, '.ssh', 'identity') ]);
     }
 
     for my $a (qw( password rhosts rhosts_rsa rsa ch_res )) {
-        $ssh->{config}->set("auth_$a", 1)
-            unless defined $ssh->{config}->get("auth_$a");
+        $config->set("auth_$a", 1)
+            unless defined $config->get("auth_$a");
     }
 }
 
@@ -226,8 +235,8 @@ sub _setup_connection {
             my @sz = Term::ReadKey::GetTerminalSize($ssh->sock);
             if (defined $sz[0]) {
                 $foundsize = 1;
-                $packet->put_int32($sz[1]); # height
                 $packet->put_int32($sz[0]); # width
+                $packet->put_int32($sz[1]); # height
                 $packet->put_int32($sz[2]); # xpix
                 $packet->put_int32($sz[3]); # ypix
             }
